/*
 * Circurs - Circular optical microresonators simulation tools
 * Kirankumar R. Hiremath (k.r.hiremath@ieee.org)
 * University of Twente, Department of Applied Mathematics 
 * P.O. Box 217, 7500AE Enschede, The Netherlands
 * (2005)
 */

/*
 * bslamvis.c
 * 1-D bend specific output to MATLAB .m -files, visualization  
 * helper routines for bslamode.c, bslamarr.c, mr.c
 */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include"bslawaveg.h"
#include"bslamvis.h"

/* for all the required stuff related with straight waveguide */
#include "metric.h"
/* mode section plot, plot commands */
void mlout_Lsecplot_rad(char *name, FILE *dat, Fcomp cp, int nbd, int nsec)
{
    int i;
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s', 'Color', 'w');\n", name);
fprintf(dat, "axis off;\n");
fprintf(dat, "alw = 1.2;\n");
fprintf(dat, "lw = 1.6;\n");
fprintf(dat, "fs = 16;\n");
fprintf(dat, "lfs = 16;\n");
fprintf(dat, "fnm = 'Helvetica';\n");
fprintf(dat, "\n");

fprintf(dat, "y0 = minf-(maxf-minf)/20.0;\n");
fprintf(dat, "y1 = maxf+(maxf-minf)/20.0;\n");
fprintf(dat, "%% y0 = minf;\n");
fprintf(dat, "%% y1 = maxf;\n");
fprintf(dat, "\n");

fprintf(dat, "h = axes('Position', [0.15 0.15 0.80 0.65], ...\n");
fprintf(dat, "       'XLim', [x0 x1], ...\n");
fprintf(dat, "       'YLim', [y0 y1], ...\n");
fprintf(dat, "       'FontSize', fs, ...\n");
fprintf(dat, "       'FontName', fnm, ...\n");
fprintf(dat, "       'LineWidth', alw, ...\n");
fprintf(dat, "       'TickDir', 'out');\n");

fprintf(dat, "axes(h);\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "box on;\n");
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");

fprintf(dat, "xlabel('(r-R)  [\\mum]', 'FontSize', lfs, 'FontName', fnm);\n");
fprintf(dat, "ylabel('|%c_{%c}^{0}|', 'FontSize', lfs, 'Fontname', fnm);\n",
        fldchr(cp), cpchr(cp));
fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Background: shading according to waveguide geometry\n");
fprintf(dat, "maxn = max(max(n));\n");
fprintf(dat, "minn = min(min(n));\n");
fprintf(dat, "for i=1:nbd+1\n");
fprintf(dat, "   if i==1 b0=x0;\n");
fprintf(dat, "   else    b0=bd(i-1);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   if i==nbd+1 b1=x1;\n");
fprintf(dat, "   else        b1=bd(i);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   pc = 1.0-(ri(i)-minn)/(maxn-minn)*0.2;\n");
fprintf(dat, "   patch([b0 b0 b1 b1], [y1 y0 y0 y1], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
	}
fprintf(dat, "%% Add field values\n");
fprintf(dat, "lw = 2.0;\n");
	if(Mlop_Colour==YES) fprintf(dat, "ls = 'b-';\n");
	else                 fprintf(dat, "ls = 'k-';\n");
	for(i=0; i<=nsec-1; ++i)
	{
fprintf(dat, "plot(pos%c%c, %c%c%c%c, ls, 'LineWidth', lw);\n", 
	     dig10(i), dig1(i), 
             fldchr(cp), cpchr(cp), dig10(i), dig1(i));
	}
fprintf(dat, "\n");
fprintf(dat, "%% Include further field section data\n");
fprintf(dat, "%% _______V\n");
fprintf(dat, "\n");
	if(nbd > 0)
	{
fprintf(dat, "%% Indicate permittivity boundaries\n");
fprintf(dat, "for i=1:nbd\n");
fprintf(dat, "   plot([bd(i), bd(i)], [y0 y1], 'k-', 'LineWidth', 0.5);\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Renew frame\n");
fprintf(dat, "plot([x0 x0 x1 x1 x0], ...\n");
fprintf(dat, "     [y1 y0 y0 y1 y1], 'k-', 'LineWidth', alw);\n");
fprintf(dat, "\n");
	}
	return;
}

/* mode section plot; combined re, im, abs, plot commands */
void mlout_bendriaplot(char *name, FILE *dat, double minf, double maxf,
                       Fcomp cp, int nbd, int nsec)
{
	int i;
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s', 'Color', 'w');\n", name);
fprintf(dat, "axis off;\n");
fprintf(dat, "alw = 1.2;\n");
fprintf(dat, "lw = 1.6;\n");
fprintf(dat, "fs = 16;\n");
fprintf(dat, "lfs = 16;\n");
fprintf(dat, "fnm = 'Helvetica';\n");
fprintf(dat, "\n");

fprintf(dat, "y0 = minf-(maxf-minf)/20.0;\n");
fprintf(dat, "y1 = maxf+(maxf-minf)/20.0;\n");
fprintf(dat, "%% y0 = minf;\n");
fprintf(dat, "%% y1 = maxf;\n");
fprintf(dat, "\n");

fprintf(dat, "h = axes('Position', [0.15 0.15 0.80 0.65], ...\n");
fprintf(dat, "       'XLim', [x0 x1], ...\n");
fprintf(dat, "       'YLim', [y0 y1], ...\n");
fprintf(dat, "       'FontSize', fs, ...\n");
fprintf(dat, "       'FontName', fnm, ...\n");
fprintf(dat, "       'LineWidth', alw, ...\n");
fprintf(dat, "       'TickDir', 'out');\n");

fprintf(dat, "axes(h);\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "box on;\n");
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");

fprintf(dat, "xlabel('(r-R) [\\mum]', 'FontSize', lfs, 'FontName', fnm);\n");
fprintf(dat, "ylabel('Re %c_%c, Im %c_%c, |%c_{%c}^{0}| [a.u.]', 'FontSize', lfs, 'Fontname', fnm);\n", 
        fldchr(cp), cpchr(cp), fldchr(cp), cpchr(cp), fldchr(cp), cpchr(cp));
fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Background: shading according to waveguide geometry\n");
fprintf(dat, "maxn = max(max(n));\n");
fprintf(dat, "minn = min(min(n));\n");
fprintf(dat, "for i=1:nbd+1\n");
fprintf(dat, "   if i==1 b0=x0;\n");
fprintf(dat, "   else    b0=bd(i-1);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   if i==nbd+1 b1=x1;\n");
fprintf(dat, "   else        b1=bd(i);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   pc = 1.0-(ri(i)-minn)/(maxn-minn)*0.2;\n");
fprintf(dat, "   patch([b0 b0 b1 b1], [y1 y0 y0 y1], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
	}
fprintf(dat, "%% Add field values\n");
fprintf(dat, "lw = 2.0;\n");

	if(Mlop_Colour==YES) fprintf(dat, "ls = 'k-';\n"); 
	else                 fprintf(dat, "ls = 'k--';\n");
	for(i=0; i<=nsec-1; ++i)
	{
fprintf(dat, "plot(pos%c%c%c%c, %c%c%c%c%c%c, ls, 'LineWidth', lw);\n", 
	                dig10(i), dig1(i), 'r', 'e',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'r', 'e');
	}
	fprintf(dat, "\n");

	if(Mlop_Colour==YES) fprintf(dat, "ls = 'r-';\n"); 
	else                 fprintf(dat, "ls = 'k-.';\n");
	for(i=0; i<=nsec-1; ++i)
	{
fprintf(dat, "plot(pos%c%c%c%c, %c%c%c%c%c%c, ls, 'LineWidth', lw);\n", 
	                dig10(i), dig1(i), 'i', 'm',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'i', 'm');
	}
	fprintf(dat, "\n");

	if(Mlop_Colour==YES) fprintf(dat, "ls = 'b-';\n"); 
	else                 fprintf(dat, "ls = 'k-';\n");
	fprintf(dat, "clear i;\n");
	for(i=0; i<=nsec-1; ++i)
	{
fprintf(dat, "plot(pos%c%c%c%c, abs(%c%c%c%c%c%c +i*%c%c%c%c%c%c), ls, 'LineWidth', lw);\n", 
	                dig10(i), dig1(i), 'r', 'e',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'r', 'e',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'i', 'm');
	}
	fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Indicate permittivity boundaries\n");
fprintf(dat, "for i=1:nbd\n");
fprintf(dat, "   plot([bd(i), bd(i)], [y0 y1], 'k-', 'LineWidth', 0.5);\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Renew frame\n");
fprintf(dat, "plot([x0 x0 x1 x1 x0], ...\n");
fprintf(dat, "     [y1 y0 y0 y1 y1], 'k-', 'LineWidth', alw);\n");
fprintf(dat, "\n");
	}
	return;
}


/* mode section plot; combined abs, phase, plot commands */
void mlout_bendaphplot(char *name, FILE *dat, double minf, double maxf,
                       Fcomp cp, int nbd, int nsec)
{
	int i;
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s', 'Color', 'w');\n", name);
fprintf(dat, "axis off;\n");
fprintf(dat, "alw = 1.2;\n");
fprintf(dat, "lw = 1.6;\n");
fprintf(dat, "fs = 16;\n");
fprintf(dat, "lfs = 16;\n");
fprintf(dat, "fnm = 'Helvetica';\n");
fprintf(dat, "left = 0.15;\n");
fprintf(dat, "width = 0.80;\n");
fprintf(dat, "\n");

fprintf(dat, "%% ---------------------------------------------------\n");
fprintf(dat, "\n");

fprintf(dat, "y0 = minf-(maxf-minf)/20.0;\n");
fprintf(dat, "y1 = maxf+(maxf-minf)/20.0;\n");
fprintf(dat, "%% y0 = minf;\n");
fprintf(dat, "%% y1 = maxf;\n");
fprintf(dat, "\n");

fprintf(dat, "h = axes('Position', [left 0.55 width 0.372], ...\n");
fprintf(dat, "       'XLim', [x0 x1], ...\n");
fprintf(dat, "       'YLim', [y0 y1], ...\n");
fprintf(dat, "       'FontSize', fs, ...\n");
fprintf(dat, "       'FontName', fnm, ...\n");
fprintf(dat, "       'LineWidth', alw, ...\n");
fprintf(dat, "       'XTickLabel', ' ', ...\n");
fprintf(dat, "       'TickDir', 'out');\n");

fprintf(dat, "axes(h);\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "box on;\n");
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");

fprintf(dat, "%% xlabel('(r-R)  [\\mum]', 'FontSize', lfs, 'FontName', fnm);\n");
fprintf(dat, "ylabel('|%c_{%c}^{0}| [a.u.]', 'FontSize', lfs, 'Fontname', fnm);\n", 
        fldchr(cp), cpchr(cp));
fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Background: shading according to waveguide geometry\n");
fprintf(dat, "maxn = max(max(n));\n");
fprintf(dat, "minn = min(min(n));\n");
fprintf(dat, "for i=1:nbd+1\n");
fprintf(dat, "   if i==1 b0=x0;\n");
fprintf(dat, "   else    b0=bd(i-1);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   if i==nbd+1 b1=x1;\n");
fprintf(dat, "   else        b1=bd(i);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   pc = 1.0-(ri(i)-minn)/(maxn-minn)*0.2;\n");
fprintf(dat, "   patch([b0 b0 b1 b1], [y1 y0 y0 y1], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
	}
fprintf(dat, "%% Add field values\n");
fprintf(dat, "lw = 2.0;\n");

	if(Mlop_Colour==YES) fprintf(dat, "ls = 'b-';\n"); 
	else                 fprintf(dat, "ls = 'k-';\n");
	fprintf(dat, "clear i;\n");
	for(i=0; i<=nsec-1; ++i)
	{
fprintf(dat, "plot(pos%c%c%c%c, abs(%c%c%c%c%c%c +i*%c%c%c%c%c%c), ls, 'LineWidth', lw);\n", 
	                dig10(i), dig1(i), 'r', 'e',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'r', 'e',
                        fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'i', 'm');
	}
	fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Indicate permittivity boundaries\n");
fprintf(dat, "for i=1:nbd\n");
fprintf(dat, "   plot([bd(i), bd(i)], [y0 y1], 'k-', 'LineWidth', 0.5);\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Renew frame\n");
fprintf(dat, "plot([x0 x0 x1 x1 x0], ...\n");
fprintf(dat, "     [y1 y0 y0 y1 y1], 'k-', 'LineWidth', alw);\n");
fprintf(dat, "\n");
	}

fprintf(dat, "%% ---------------------------------------------------\n");
fprintf(dat, "\n");

fprintf(dat, "y0 = -3.0;\n");
fprintf(dat, "y1 =  0.7;\n");
fprintf(dat, "\n");

fprintf(dat, "h = axes('Position', [left 0.15 width 0.372], ...\n");
fprintf(dat, "       'XLim', [x0 x1], ...\n");
fprintf(dat, "       'YLim', [y0 y1], ...\n");
fprintf(dat, "       'FontSize', fs, ...\n");
fprintf(dat, "       'FontName', fnm, ...\n");
fprintf(dat, "       'LineWidth', alw, ...\n");
fprintf(dat, "       'TickDir', 'out');\n");

fprintf(dat, "axes(h);\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "box on;\n");
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");

fprintf(dat, "xlabel('(r-R)  [\\mum]', 'FontSize', lfs, 'FontName', fnm);\n");
fprintf(dat, "ylabel('arg %c_{%c}^{0} / \\pi', 'FontSize', lfs, 'Fontname', fnm);\n", 
        fldchr(cp), cpchr(cp));
fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Background: shading according to waveguide geometry\n");
fprintf(dat, "maxn = max(max(n));\n");
fprintf(dat, "minn = min(min(n));\n");
fprintf(dat, "for i=1:nbd+1\n");
fprintf(dat, "   if i==1 b0=x0;\n");
fprintf(dat, "   else    b0=bd(i-1);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   if i==nbd+1 b1=x1;\n");
fprintf(dat, "   else        b1=bd(i);\n");
fprintf(dat, "   end\n");
fprintf(dat, "   pc = 1.0-(ri(i)-minn)/(maxn-minn)*0.2;\n");
fprintf(dat, "   patch([b0 b0 b1 b1], [y1 y0 y0 y1], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
	}
fprintf(dat, "%% Add field values\n");
fprintf(dat, "lw = 2.0;\n");

	if(Mlop_Colour==YES) fprintf(dat, "ls = 'b-';\n"); 
	else                 fprintf(dat, "ls = 'k-';\n");
	fprintf(dat, "clear i;\n");
	fprintf(dat, "pbu = 0;\n");

	fprintf(dat, "Ey = [");
	for(i=0; i<=nsec-1; ++i)
	{
	    fprintf(dat, "(%c%c%c%c%c%c +i*%c%c%c%c%c%c) ",
		   fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'r', 'e',
		   fldchr(cp), cpchr(cp), dig10(i), dig1(i), 'i', 'm');
	}
	fprintf(dat,"];\n");

	fprintf(dat, "pos = [");
	for(i=0; i<=nsec-1; ++i)
	{
	    fprintf(dat, "pos%c%c%c%c ", dig10(i), dig1(i), 'r', 'e');
	}
	fprintf(dat,"];\n");

	fprintf(dat,"plot( pos, unwrap(angle(Ey))/pi, ls, 'LineWidth', lw);");

	fprintf(dat, "\n");

	if(nbd > 0)
	{
fprintf(dat, "%% Indicate permittivity boundaries\n");
fprintf(dat, "for i=1:nbd\n");
fprintf(dat, "   plot([bd(i), bd(i)], [y0 y1], 'k-', 'LineWidth', 0.5);\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Renew frame\n");
fprintf(dat, "plot([x0 x0 x1 x1 x0], ...\n");
fprintf(dat, "     [y1 y0 y0 y1 y1], 'k-', 'LineWidth', alw);\n");
fprintf(dat, "\n");
	}
	return;
}

/* bend waveguide: geometry for interference visualization */
#define BMAXNUMDISCS 1000
void mlout_bendgeoxz(FILE *dat, BSlabWaveguide bend, 
                    double xbeg, double xend, double zbeg, double zend) 
{
	fprintf(dat, "%% Bend Waveguide: Geometry\n");
	fprintf(dat, "R = %g;\n", bend.R);
	fprintf(dat, "nlX = %d;\n", bend.wg.nx);
	fprintf(dat, "bdX = [ ");
	for(int j=0; j<=bend.wg.nx; ++j) 
		fprintf(dat, "%g ", bend.wg.hx(j));
	fprintf(dat, "];\n");
	fprintf(dat, "n = [ ");
	for(int j=0; j<=bend.wg.nx+1; ++j) 
	{
		fprintf(dat, "%g ", bend.wg.n(j));
	}
	fprintf(dat, "];\n");

	int nd = 0;
        Dvector pos(BMAXNUMDISCS);
	fprintf(dat, "%% Radial discontinuities\n");
	for(int i=0; i<=bend.wg.nx; ++i)
	{
		if(fabs(bend.wg.eps(i)-bend.wg.eps(i+1))>1.0e-10)
		{
			pos(nd) = bend.wg.hx(i);
			++nd;
		}
	}

	fprintf(dat, "nhd = %d;\n", nd);
	fprintf(dat, "hdpos = [ ");
	for(int i=0; i<=nd-1; ++i) fprintf(dat, "%g ", pos(i));
	fprintf(dat, "];\n");
	fprintf(dat, "\n");

	return;
}

/* sketch of permittivity boundaries: outline the geometry, bend waveguide */
void mlout_bendgeooutline(FILE *dat)
{
	fprintf(dat, "pv = linspace(0, 2.0*pi, 1000);\n");
	fprintf(dat, "for i=1:nhd\n");
        fprintf(dat, "   p = R+hdpos(i);\n");
        fprintf(dat, "   plot(p*cos(pv), p*sin(pv), ls, 'LineWidth', lw);\n");
        fprintf(dat, "end\n");
        fprintf(dat, "\n");
        return;
}

/* interference plot, bend waveguide */
void mlout_bendimage(Fcomp cp, char *name, FILE *dat)
{
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s', 'Color', 'w');\n", name);
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");
	mlout_lincolormap(dat);
fprintf(dat, "\n");
fprintf(dat, "%% adjust intensity range to actual field\n");
fprintf(dat, "maxf = max(max(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "minf = min(min(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "\n");
fprintf(dat, "%% Intensity image\n");
fprintf(dat, "imagesc(z, x, %c%c, [minf, maxf]);\n", fldchr(cp), cpchr(cp)); 
fprintf(dat, "\n");
fprintf(dat, "%% Adjust axes and labels\n");
fprintf(dat, "box on;\n");
fprintf(dat, "axis([zbeg, zend, xbeg, xend]);\n");
fprintf(dat, "set(gca, 'FontSize', 10, ...\n");
fprintf(dat, "         'LineWidth', 1.5, ...\n");
fprintf(dat, "         'Clipping', 'off', ...\n");
fprintf(dat, "         'YDir', 'normal', ...\n");
fprintf(dat, "         'TickDir', 'out', ...\n");
fprintf(dat, "         'PlotBoxAspectRatio', [(zend-zbeg)/(xend-xbeg) 0.95 0.95]);\n");
fprintf(dat, "xlabel('z [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "ylabel('x [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "\n");
	mlout_sketchinit(dat);
	mlout_bendgeooutline(dat);
	return;
}

/* interference animation, bend waveguide */
void mlout_bendmovie(Fcomp cp, char *name, FILE *dat, int ntfr, double dt,
                     double om, double famp)
{
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s', 'Color', 'w');\n", name);
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");
	mlout_magcolormap(dat);
fprintf(dat, "\n");
fprintf(dat, "%% intensity range\n");
fprintf(dat, "maxf = %g;\n", famp);
fprintf(dat, "\n");

fprintf(dat, "for ti=0:%d\n", ntfr-1);
fprintf(dat, "   t = ti*%.10g;\n", dt);
fprintf(dat, "   fld = %c%c_re*cos(%.10g*t) - %c%c_im*sin(%.10g*t);\n",
             fldchr(cp), cpchr(cp), om, fldchr(cp), cpchr(cp), om); 

fprintf(dat, "   %% Intensity image\n");
fprintf(dat, "   imagesc(z, x, fld, [-maxf, maxf]);\n");
fprintf(dat, "\n");
fprintf(dat, "   %% Adjust axes and labels\n");
fprintf(dat, "   box on;\n");
fprintf(dat, "   axis([zbeg, zend, xbeg, xend]);\n");
fprintf(dat, "   set(gca, 'FontSize', 10, ...\n");
fprintf(dat, "         'LineWidth', 1.5, ...\n");
fprintf(dat, "         'Clipping', 'off', ...\n");
fprintf(dat, "         'YDir', 'normal', ...\n");
fprintf(dat, "         'TickDir', 'out', ...\n");
fprintf(dat, "         'PlotBoxAspectRatio', [(zend-zbeg)/(xend-xbeg) 0.95 0.95]);\n");
fprintf(dat, "   xlabel('z [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "   ylabel('x [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "\n");
	mlout_sketchinit(dat);
	mlout_bendgeooutline(dat);
fprintf(dat, "   %% show time-position\n");
fprintf(dat, "   text(zend-(zend-zbeg)/30, xbeg+(xend-xbeg)/30, ...\n");
fprintf(dat, "      sprintf('t = %%#4.2f fs', t), 'Color', 'w', ...\n");
fprintf(dat, "      'HorizontalAlignment', 'right', ...\n");
fprintf(dat, "      'VerticalAlignment', 'bottom', 'FontSize', 12);\n");  
fprintf(dat, "   \n");
fprintf(dat, "   if ti == 0\n");
fprintf(dat, "      %% reserve memory\n");
fprintf(dat, "      M = moviein(%d);\n", ntfr);     
fprintf(dat, "   end\n");
fprintf(dat, "   %% store frames\n");
fprintf(dat, "   M(:,ti+1) = getframe;\n");  
fprintf(dat, "   hold off;\n");
	if(Mlop_Print != YES) 
	{
fprintf(dat, "   %%%% Print frame to file\n");
fprintf(dat, "   %% set(gcf, 'InvertHardcopy', 'off');\n");
fprintf(dat, "   %% print('-dpng', '-r75', sprintf('%s_f%%d',ti));\n", name);
	}
	else
	{
fprintf(dat, "   %% Print figure to file\n");
fprintf(dat, "   set(gcf, 'InvertHardcopy', 'off');\n");
fprintf(dat, "   print('-dpng', '-r75', sprintf('%s_f%%d',ti));\n", name);
	}
fprintf(dat, "\n");
fprintf(dat, "end\n");

fprintf(dat, "set(gcf, 'Name', 'CW wave propagation');\n");
fprintf(dat, "\n");
	if(Mlop_Print != YES) 
	{
fprintf(dat, "%%%% Save movie as a video file\n");
fprintf(dat, "%%movie2avi(M, '%s', ...\n", name);
fprintf(dat, "%%   'fps', 15, ...\n");
fprintf(dat, "%%   'compression', 'none', ...\n");
fprintf(dat, "%%   'quality', 100, ...\n");
fprintf(dat, "%%   'videoname', 'CW wave propagation');\n");
fprintf(dat, "\n");
fprintf(dat, "%% ... show it. \n");
fprintf(dat, "movie(M, 20)\n");         
	}
	else
	{
fprintf(dat, "%% Save movie as a video file\n");
fprintf(dat, "movie2avi(M, '%s', ...\n", name);
fprintf(dat, "   'fps', 15, ...\n");
fprintf(dat, "   'compression', 'none', ...\n");
fprintf(dat, "   'quality', 100, ...\n");
fprintf(dat, "   'videoname', 'CW wave propagation');\n");
fprintf(dat, "\n");
fprintf(dat, "%% ... show it. \n");
fprintf(dat, "%% movie(M, 20)\n");         
	}
fprintf(dat, "\n");
	return;
}

/* ------------------------------------------------------------------- */
/* microresonator field plots, helper functions */

/* waveguide geometry and field extrema */
void mlout_micresgeo(FILE *dat, BSlabWaveguide b, Waveguide si, Waveguide so) 
{
        fprintf(dat, "%% Microresonator geometry\n");
        fprintf(dat, "Rc = %g;\n", b.R+b.wg.hx(1));
	if(   fabs(b.wg.hx(1)-b.wg.hx(0))>COMPTOL_HX 
	   && fabs(b.wg.n(0)-b.wg.n(1))>COMPTOL_N)
	        fprintf(dat, "Ri = %g;\n", b.R+b.wg.hx(0));
	else 
	        fprintf(dat, "Ri = %g;\n", b.R+b.wg.hx(1));
        fprintf(dat, "w_i = %g;\n", si.hx(1)-si.hx(0));
//        fprintf(dat, "g_i = %g;\n", si.hx(0)-(b.R+b.wg.hx(0)));
	fprintf(dat, "g_i = %g;\n", si.hx(0)-(b.R+b.wg.hx(1)));
        fprintf(dat, "w_o = %g;\n", so.hx(1)-so.hx(0));
//        fprintf(dat, "g_o = %g;\n", so.hx(0)-(b.R+b.wg.hx(0)));
	fprintf(dat, "g_o = %g;\n", so.hx(0)-(b.R+b.wg.hx(1)));
        fprintf(dat, "\n");
        return;
}

/* sketch of permittivity boundaries: outline the resonator geometry */
void mlout_micresgeooutline(FILE *dat)
{
        fprintf(dat, "plot([zbeg, zend], [Rc+g_i+w_i, Rc+g_i+w_i], ls, 'LineWidth', lw);\n");
        fprintf(dat, "plot([zbeg, zend], [Rc+g_i, Rc+g_i], ls, 'LineWidth', lw);\n");
        fprintf(dat, "plot([zbeg, zend], [-Rc-g_o-w_o, -Rc-g_o-w_o], ls, 'LineWidth', lw);\n");
        fprintf(dat, "plot([zbeg, zend], [-Rc-g_o, -Rc-g_o], ls, 'LineWidth', lw);\n");
        fprintf(dat, "phi = linspace(0, 2*pi, 500);\n");
        fprintf(dat, "lcx = Rc*cos(phi); lcz = Rc*sin(phi);\n");
        fprintf(dat, "plot(lcz, lcx, ls, 'LineWidth', lw);\n");
        fprintf(dat, "lcx = Ri*cos(phi); lcz = Ri*sin(phi);\n");
        fprintf(dat, "plot(lcz, lcx, ls, 'LineWidth', lw);\n");
        fprintf(dat, "\n");
        return;
}

/* interference plot, microresonator structure */
void mlout_micresgenimage(Fcomp cp, char *name, char *desc, FILE *dat)
{
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s,  %s(x, z)', 'Color', 'w');\n", name, desc);
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");
fprintf(dat, "%% adjust intensity range to actual field\n");
fprintf(dat, "maxf = max(max(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "minf = min(min(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "if minf >= maxf\n");
fprintf(dat, "   minf = minf-1.0;\n");
fprintf(dat, "   maxf = minf+2.0;\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Intensity image\n");
fprintf(dat, "imagesc(z, x, %c%c, [minf, maxf]);\n", fldchr(cp), cpchr(cp)); 
fprintf(dat, "\n");
	mlout_contours(cp, dat);
fprintf(dat, "%% Adjust axes and labels\n");
fprintf(dat, "box on;\n");
fprintf(dat, "axis([zbeg, zend, xbeg, xend]);\n");
fprintf(dat, "set(gca, 'FontSize', 10, ...\n");
fprintf(dat, "         'LineWidth', 1.5, ...\n");
fprintf(dat, "         'Clipping', 'off', ...\n");
fprintf(dat, "         'YDir', 'normal', ...\n");
fprintf(dat, "         'TickDir', 'out', ...\n");
fprintf(dat, "         'PlotBoxAspectRatio', [(zend-zbeg)/(xend-xbeg) 0.95 0.95]);\n");
fprintf(dat, "xlabel('z [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "ylabel('x [\\mum]', 'FontSize', 12);\n");
fprintf(dat, "\n");
	mlout_sketchinit(dat);
	mlout_micresgeooutline(dat);
	return;
}

/* interference animation, microresonator structure */
void mlout_micresmovie(Fcomp cp, char *name, char *desc, FILE *dat, 
                       int ntfr, double dt, double om, double famp)
{
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s,  %s(x, z, t)', 'Color', 'w');\n", name, desc);
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");
	mlout_magcolormap(dat);
fprintf(dat, "%% intensity range\n");
fprintf(dat, "maxf = %g;\n", famp);
fprintf(dat, "\n");

fprintf(dat, "%% Loop over one time period\n");
fprintf(dat, "for ti=0:%d\n", ntfr-1);
fprintf(dat, "   t = ti*%.10g;\n", dt);
fprintf(dat, "   fld = %c%c_re*cos(%.10g*t) - %c%c_im*sin(%.10g*t);\n",
             fldchr(cp), cpchr(cp), om, fldchr(cp), cpchr(cp), om); 

fprintf(dat, "   %% Intensity image\n");
fprintf(dat, "   imagesc(z, x, fld, [-maxf, maxf]);\n");
fprintf(dat, "\n");
	mlout_contours(dat);
fprintf(dat, "   %% Adjust axes and labels\n");
fprintf(dat, "   box on;\n");
fprintf(dat, "   axis([zbeg, zend, xbeg, xend]);\n");
fprintf(dat, "   set(gca, 'FontSize', 24, ...\n");
fprintf(dat, "         'LineWidth', 1.5, ...\n");
fprintf(dat, "         'Clipping', 'off', ...\n");
fprintf(dat, "         'YDir', 'normal', ...\n");
fprintf(dat, "         'TickDir', 'out', ...\n");
fprintf(dat, "         'PlotBoxAspectRatio', [(zend-zbeg)/(xend-xbeg) 0.95 0.95]);\n");
fprintf(dat, "   xlabel('z [\\mum]', 'FontSize', 24);\n");
fprintf(dat, "   ylabel('x [\\mum]', 'FontSize', 24);\n");
fprintf(dat, "\n");
	mlout_sketchinit(dat);
	mlout_micresgeooutline(dat);
fprintf(dat, "   %% show time-position\n");
fprintf(dat, "   %%text(zend-(zend-zbeg)/30, xbeg+(xend-xbeg)/30, ...\n");
fprintf(dat, "   %%   sprintf('t = %%#4.2f fs', t), 'Color', 'w', ...\n");
fprintf(dat, "   %%   'HorizontalAlignment', 'right', ...\n");
fprintf(dat, "   %%   'VerticalAlignment', 'bottom', 'FontSize', 12);\n");  
fprintf(dat, "   \n");
fprintf(dat, "   if ti == 0\n");
fprintf(dat, "      %% reserve memory\n");
fprintf(dat, "      M = moviein(%d);\n", ntfr);     
fprintf(dat, "   end\n");
fprintf(dat, "   %% store frames\n");
fprintf(dat, "   M(:,ti+1) = getframe;\n");  
fprintf(dat, "   hold off;\n");
	if(Mlop_Print != YES) 
	{
fprintf(dat, "   %%%% Print frame to file\n");
fprintf(dat, "   %% print('-dpng', '-r75', sprintf('%s_f%%d',ti));\n", name);
	}
	else
	{
fprintf(dat, "   %% Print figure to file\n");
fprintf(dat, "   print('-dpng', '-r75', sprintf('%s_f%%d',ti));\n", name);
	}
fprintf(dat, "\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
	if(Mlop_Print != YES) 
	{
fprintf(dat, "%%%% Save movie as a video file\n");
fprintf(dat, "%%movie2avi(M, '%s', ...\n", name);
fprintf(dat, "%%   'fps', 15, ...\n");
fprintf(dat, "%%   'compression', 'none', ...\n");
fprintf(dat, "%%   'quality', 100, ...\n");
fprintf(dat, "%%   'videoname', '%s(x, z, t)');\n", desc);
fprintf(dat, "\n");
fprintf(dat, "%% ... show it. \n");
fprintf(dat, "movie(M, 20)\n");         
	}
	else
	{
fprintf(dat, "%% Save movie as a video file\n");
fprintf(dat, "movie2avi(M, '%s', ...\n", name);
fprintf(dat, "   'fps', 15, ...\n");
fprintf(dat, "   'compression', 'none', ...\n");
fprintf(dat, "   'quality', 100, ...\n");
fprintf(dat, "   'videoname', '%s(x, z, t)');\n", desc);
fprintf(dat, "\n");
fprintf(dat, "%% ... show it. \n");
fprintf(dat, "%% movie(M, 20)\n");         
	}
fprintf(dat, "\n");
	return;
}

/* field viewer .m-file: top, title and globals, microresonator geometry */
void mlout_micresviewertop(FILE *dat, char *name, 
                           Polarization p, double lambda)
{
fprintf(dat, "%% %s.m\n", name);
fprintf(dat, "%% Circurs field solution, viewer GUI\n");
fprintf(dat, "function %s\n", name);
fprintf(dat, "\n");
fprintf(dat, "close all; clear global;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Polarisation\n");
fprintf(dat, "pol = 'T%c';\n", polCHR(p));
fprintf(dat, "%% Wavelength\n");
fprintf(dat, "lambda = %.10g;\n", lambda);
fprintf(dat, "\n");
fprintf(dat, "%% Field and structure data\n");
fprintf(dat, "global Rc Ri w_i g_i w_o g_o n;\n");
fprintf(dat, "global xbeg xend numx x zbeg zend numz z;\n");
fprintf(dat, "global Ex_re Ex_im Ey_re Ey_im Ez_re Ez_im;\n");
fprintf(dat, "global Hx_re Hx_im Hy_re Hy_im Hz_re Hz_im;\n");
fprintf(dat, "\n");
return;
}

/* field viewer .m-file: viewer commands, microresonator geometry */
void mlout_micresfldviewer(FILE *dat, char *name)
{
fprintf(dat, "\n");
fprintf(dat, "%% -------------------------------------------------------------------------\n");
fprintf(dat, "%% Viewer commands \n");
fprintf(dat, "\n");
fprintf(dat, "clear Ex; clear Ey; clear Ez; clear Hx; clear Hy; clear Hz;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Poynting vector\n");
fprintf(dat, "global Sx Sz;\n");
fprintf(dat, "Sx=0.5*real((Ey_re+i*Ey_im).*(Hz_re-i*Hz_im)-(Ez_re+i*Ez_im).*(Hy_re-i*Hy_im)); \n");
fprintf(dat, "Sz=0.5*real((Ex_re+i*Ex_im).*(Hy_re-i*Hy_im)-(Ey_re+i*Ey_im).*(Hx_re-i*Hx_im)); \n");
fprintf(dat, "\n");
fprintf(dat, "%% Energy density of the optical field\n");
fprintf(dat, "global W;\n");
fprintf(dat, "mu0 = 1.2566370614; ep0 = 8.854187817E-6;\n");
fprintf(dat, "W = 0.25*(mu0*(Hx_re.*Hx_re+Hx_im.*Hx_im+Hy_re.*Hy_re+Hy_im.*Hy_im ...\n");
fprintf(dat, "              +Hz_re.*Hz_re+Hz_im.*Hz_im ) ...\n");
fprintf(dat, "         +ep0.*n.*n.*(Ex_re.*Ex_re+Ex_im.*Ex_im+Ey_re.*Ey_re+Ey_im.*Ey_im ...\n");
fprintf(dat, "                     +Ez_re.*Ez_re+Ez_im.*Ez_im ));\n");
fprintf(dat, "\n");
fprintf(dat, "%% Maximum field levels\n");
fprintf(dat, "global max_E max_H max_S max_W min_n max_n;\n");
fprintf(dat, "max_E = max(max(Ex_re.*Ex_re+Ex_im.*Ex_im));\n");
fprintf(dat, "m = max(max(Ey_re.*Ey_re+Ey_im.*Ey_im));\n");
fprintf(dat, "if m>max_E max_E = m; end\n");
fprintf(dat, "m = max(max(Ez_re.*Ez_re+Ez_im.*Ez_im));\n");
fprintf(dat, "if m>max_E max_E = m; end\n");
fprintf(dat, "max_E = sqrt(max_E);\n");
fprintf(dat, "max_H = max(max(Hx_re.*Hx_re+Hx_im.*Hx_im));\n");
fprintf(dat, "m = max(max(Hy_re.*Hy_re+Hy_im.*Hy_im));\n");
fprintf(dat, "if m>max_H max_H = m; end\n");
fprintf(dat, "m = max(max(Hz_re.*Hz_re+Hz_im.*Hz_im));\n");
fprintf(dat, "if m>max_H max_H = m; end\n");
fprintf(dat, "max_H = sqrt(max_H);\n");
fprintf(dat, "max_S = max(max(Sx));\n");
fprintf(dat, "m = max(max(Sz));\n");
fprintf(dat, "if m>max_S max_S = m; end\n");
fprintf(dat, "max_W = max(max(W));\n");
fprintf(dat, "max_n = max(max(n));\n");
fprintf(dat, "min_n = min(min(n));\n");
fprintf(dat, "if min_n >= max_n max_n = min_n+1; end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Linear colormap\n");
fprintf(dat, "global lin_blue;\n");
fprintf(dat, "mi = 32; mlv = 0.2; lin_blue = zeros(64, 3);\n");
fprintf(dat, "lin_blue(1:mi, 3) = linspace(0, 1,   mi)';\n");
fprintf(dat, "lin_blue(1:mi, 2) = linspace(0, mlv, mi)';\n");
fprintf(dat, "lin_blue(1:mi, 1) = linspace(0, mlv, mi)';\n");
fprintf(dat, "lin_blue(mi+1:64, 3) = 1;\n");
fprintf(dat, "lin_blue(mi+1:64, 2) = linspace(mlv, 1, 64-mi)';\n");
fprintf(dat, "lin_blue(mi+1:64, 1) = linspace(mlv, 1, 64-mi)';\n");
fprintf(dat, "\n");
fprintf(dat, "%% Colormap: magnified zero level\n");
fprintf(dat, "global mag_blue;\n");
fprintf(dat, "mag_blue = zeros(256, 3);\n");
fprintf(dat, "cpd = 0.02; cphb= 0.75; cpho= 0.25; cpa = atan(256*cpd/2);\n");
fprintf(dat, "for idx = 0:255\n");
fprintf(dat, "   t = 0.5*(atan(cpd*(idx-256/2))/cpa+1);\n");
fprintf(dat, "   mag_blue(idx+1, 3) = (2-4*cphb)*t*t+(4*cphb-1)*t;\n");
fprintf(dat, "   mag_blue(idx+1, 1) = (2-4*cpho)*t*t+(4*cpho-1)*t;\n");
fprintf(dat, "   mag_blue(idx+1, 2) = mag_blue(idx+1, 1);\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% A few style variables ...\n");
fprintf(dat, "global col_fbg col_txt col_abg col_atx col_but col_btx fntsz;\n");
fprintf(dat, "col_fbg = [0.77 0.80 0.87]; col_txt = [0.00 0.00 0.00];\n");
fprintf(dat, "col_abg = [1.00 1.00 1.00]; col_atx = [0.00 0.00 0.00];\n");
fprintf(dat, "col_but = [0.00 0.47 0.48]; col_btx = [1.00 1.00 1.00];\n");
fprintf(dat, "fntsz = 10;\n");
fprintf(dat, "\n");
fprintf(dat, "%% The viewer window\n");
fprintf(dat, "global fgr;\n");
fprintf(dat, "fgr = figure('NumberTitle', 'off', 'Name', 'fldxyA', 'Color', col_fbg, ...\n");
fprintf(dat, "             'Units', 'pixels', 'Menubar', 'none');\n");
fprintf(dat, "\n");
fprintf(dat, "%% Adjust figure extension, respect aspect ratio of the data as far as possible,\n");
fprintf(dat, "%% Select figure position\n");
fprintf(dat, "dx = xend-xbeg; dz = zend-zbeg;\n");
fprintf(dat, "if dx<0.25*dz dx = 0.25*dz; end\n");
fprintf(dat, "if dz<0.25*dx dz = 0.25*dx; end\n");
fprintf(dat, "axw = round(sqrt(144400*dz/dx)); axh = round(axw*dx/dz);\n");
fprintf(dat, "global csf_xaw csf_zaw;\n");
fprintf(dat, "csf_zaw = axw; csf_xaw = axh;\n");
fprintf(dat, "fgw = axw+80+180; fgh = axh+2*40;\n");
fprintf(dat, "axw = axw/fgw; axh = axh/fgh;\n");
fprintf(dat, "axpx = 60/fgw; axpy = 40/fgh;\n");
fprintf(dat, "cmpx = axpx+axw+7/fgw; cmpw = 13/fgw;\n");
fprintf(dat, "bupx = cmpx+cmpw+45/fgw; buw = 1.0-10/fgw-bupx; busep = 2/fgw;\n");
fprintf(dat, "set(0, 'Units', 'pixels');\n");
fprintf(dat, "scrsz = get(0, 'ScreenSize');\n");
fprintf(dat, "if fgw > scrsz(3)*0.8 \n");
fprintf(dat, "   s = scrsz(3)*0.8/fgw; fgw = fgw*s; fgh = fgh*s;\n");
fprintf(dat, "end\n");
fprintf(dat, "if fgh > scrsz(4)*0.8 \n");
fprintf(dat, "   s = scrsz(4)*0.8/fgh; fgw = fgw*s; fgh = fgh*s;\n");
fprintf(dat, "end\n");
fprintf(dat, "fgpx = round(scrsz(1)+scrsz(3)*0.05); fgpy = round(scrsz(2)+scrsz(4)*0.95)-fgh;\n");
fprintf(dat, "set(fgr, 'Position', [fgpx fgpy fgw fgh]);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Plot container: global state \n");
fprintf(dat, "global pl_fld pl_fldre pl_fldim pl_tp pl_min pl_max pl_amin pl_amax;\n");
fprintf(dat, "global pl_cp pl_img pl_afo pl_tih an_nump;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Initial plot: basic field component \n");
fprintf(dat, "if pol == 'TE'\n");
fprintf(dat, "   pl_tp = 0.0; pl_cp = 'E_y'; pl_afo = 'f';\n");
fprintf(dat, "   pl_fldre = Ey_re; pl_fldim = Ey_im; pl_min = -max_E; pl_max =  max_E;\n");
fprintf(dat, "else\n");
fprintf(dat, "   pl_tp = 0.0; pl_cp = 'H_y'; pl_afo = 'f';\n");
fprintf(dat, "   pl_fldre = Hy_re; pl_fldim = Hy_im; pl_min = -max_H; pl_max =  max_H;\n");
fprintf(dat, "end\n");
fprintf(dat, "an_nump = 10;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Refine the plot window\n");
fprintf(dat, "global axs;\n");
fprintf(dat, "axs = axes;\n");
fprintf(dat, "pl_fld = pl_fldre*cos(2*pi*pl_tp)-pl_fldim*sin(2*pi*pl_tp);\n");
fprintf(dat, "pl_amin = min(min(pl_fld)); pl_amax = max(max(pl_fld));\n");
fprintf(dat, "pl_img = imagesc(z, x, pl_fld, [pl_min, pl_max]);\n");
fprintf(dat, "set(axs, 'Position', [axpx axpy axw axh], 'Units', 'normalized', ...\n");
fprintf(dat, "         'YDir', 'normal', 'ButtonDownFcn', {@clbf_crossh}, ...\n");
fprintf(dat, "         'XLim', [zbeg, zend], 'YLim', [xbeg, xend], ...\n");
fprintf(dat, "         'TickDir', 'in', 'FontSize', fntsz);\n");
fprintf(dat, "xlabel('z [\\mum]', 'FontSize', fntsz); ylabel('x [\\mum]', 'FontSize', fntsz);\n");
fprintf(dat, "global tle;\n");
fprintf(dat, "tle = title(' ', 'FontSize', fntsz+2);\n");
fprintf(dat, "pl_tih = text(zend-(zend-zbeg)/30, xbeg+(xend-xbeg)/30, ...\n");
fprintf(dat, "              sprintf('t = %%#4.2f T', pl_tp), 'Color', 'w', ...\n");
fprintf(dat, "              'HorizontalAlignment', 'right', ...\n");
fprintf(dat, "              'VerticalAlignment', 'bottom', 'FontSize', fntsz);\n");
fprintf(dat, "hold on; box on; \n");
fprintf(dat, "\n");
fprintf(dat, "%% The initial plot\n");
fprintf(dat, "set(pl_img, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "plot([zbeg, zend], [Rc+g_i+w_i, Rc+g_i+w_i], ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "plot([zbeg, zend], [Rc+g_i, Rc+g_i], ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "plot([zbeg, zend], [-Rc-g_o-w_o, -Rc-g_o-w_o], ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "plot([zbeg, zend], [-Rc-g_o, -Rc-g_o], ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "phi = linspace(0, 2*pi, 500);\n");
fprintf(dat, "lcx = Rc*cos(phi); lcz = Rc*sin(phi);\n");
fprintf(dat, "plot(lcz, lcx, ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "lcx = Ri*cos(phi); lcz = Ri*sin(phi);\n");
fprintf(dat, "plot(lcz, lcx, ...\n");
fprintf(dat, "     'w-', 'LineWidth', 1.0, 'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Crosshair \n");
fprintf(dat, "global chh chv chx chz;\n");
fprintf(dat, "chx = xend; chz = zend;\n");
fprintf(dat, "axes(axs);\n");
fprintf(dat, "chh = plot([zbeg zend], [chx chx], ...\n");
fprintf(dat, "           'LineStyle', '-.', 'LineWidth', 0.5, 'Color', [0.5 0.5 0.5], ...\n");
fprintf(dat, "           'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "chv = plot([chz chz], [xbeg xend], ...\n");
fprintf(dat, "           'LineStyle', '-.', 'LineWidth', 0.5, 'Color', [0.5 0.5 0.5], ...\n");
fprintf(dat, "           'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "\n");
fprintf(dat, "%% The colormap axis\n");
fprintf(dat, "global clb clb_img;\n");
fprintf(dat, "clb = axes;\n");
fprintf(dat, "rge = linspace(pl_min, pl_max, 64);\n");
fprintf(dat, "clb_img = imagesc([0 1], rge, [rge',rge'], [pl_min, pl_max]);\n");
fprintf(dat, "set(clb, 'Position', [cmpx axpy cmpw axh], 'Units', 'normalized', ...\n");
fprintf(dat, "         'YDir', 'normal', 'ButtonDownFcn', {@clbf_contour}, ...\n");
fprintf(dat, "         'XLim', [0, 1], 'YLim', [pl_min, pl_max], 'XTick', [], ...\n");
fprintf(dat, "         'YAxisLocation', 'right', 'TickDir', 'in', 'FontSize', fntsz);\n");
fprintf(dat, "set(clb_img, 'ButtonDownFcn', {@clbf_contour});\n");
fprintf(dat, "hold on;\n");
fprintf(dat, "\n");
fprintf(dat, "%% The contour positioner\n");
fprintf(dat, "global cont_ah cont_minh cont_maxh cont_hdl cont_num; \n");
fprintf(dat, "lv = pl_min;\n");
fprintf(dat, "cont_ah = plot([0 1], [lv lv], ...\n");
fprintf(dat, "               'LineStyle', '-', 'LineWidth', 0.5, 'Color', [0.5 0.5 0.5], ...\n");
fprintf(dat, "               'ButtonDownFcn', {@clbf_contour});\n");
fprintf(dat, "cont_minh = plot([0 1], [pl_amin pl_amin], ...\n");
fprintf(dat, "                 'LineStyle', '-', 'LineWidth', 0.5, 'Color', [1.0 1.0 1.0], ...\n");
fprintf(dat, "                 'ButtonDownFcn', {@clbf_contour});\n");
fprintf(dat, "cont_maxh = plot([0 1], [pl_amax pl_amax], ...\n");
fprintf(dat, "                 'LineStyle', '-', 'LineWidth', 0.5, 'Color', [1.0 1.0 1.0], ...\n");
fprintf(dat, "                 'ButtonDownFcn', {@clbf_contour});\n");
fprintf(dat, "cont_num = 0;\n");
fprintf(dat, "\n");
fprintf(dat, "%% -------------------------------------------------------------------------\n");
fprintf(dat, "%% The gui control objects \n");
fprintf(dat, "\n");
fprintf(dat, "uc_dummy = uicontrol('Style', 'text', 'String', 'M', 'Units', 'normalized', ...\n");
fprintf(dat, "                     'FontSize', fntsz, 'Visible', 'off');\n");
fprintf(dat, "dext = get(uc_dummy, 'Extent'); delete(uc_dummy);\n");
fprintf(dat, "uch0 = dext(4);\n");
fprintf(dat, "uch = (axh-37*busep)/11;\n");
fprintf(dat, "if uch0>uch uch0 = uch; end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Annotation: z-coordinate \n");
fprintf(dat, "uch = uch0; ucpy = axpy; ucpx = bupx;\n");
fprintf(dat, "uc_zl = uicontrol('Style', 'text', 'String', 'z/um', 'Units', 'normalized', ...\n");
fprintf(dat, "                  'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                  'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "p = get(uc_zl, 'Extent'); ucw = p(3);\n");
fprintf(dat, "set(uc_zl, 'Position', [ucpx ucpy ucw uch]);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Input field: z-coordinate \n");
fprintf(dat, "global uc_zf;\n");
fprintf(dat, "ucpx = ucpx+busep+ucw; ucw = buw-busep-ucw-busep-(buw-2*busep)/3;\n");
fprintf(dat, "uc_zf = uicontrol('Style', 'edit', 'Callback', {@cbf_zfld}, ...\n");
fprintf(dat, "                  'String', num2str(chz), 'Min', 1, 'Max', 1, ...\n");
fprintf(dat, "                  'TooltipString', 'View & set z-position', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                  'BackgroundColor', col_abg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: vertical cross section\n");
fprintf(dat, "ucpx = ucpx+busep+ucw; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_vc = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_crosssec, 'v'}, ...\n");
fprintf(dat, "                  'String', '|', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Vertical field section', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Annotation: x-coordinate \n");
fprintf(dat, "ucpy = ucpy+uch+busep; ucpx = bupx;\n");
fprintf(dat, "uc_xl = uicontrol('Style', 'text', 'String', 'x/um', 'Units', 'normalized', ...\n");
fprintf(dat, "                  'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                  'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "p = get(uc_xl, 'Extent'); ucw = p(3);\n");
fprintf(dat, "set(uc_xl, 'Position', [ucpx ucpy ucw uch]);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Input field: x-coordinate \n");
fprintf(dat, "global uc_xf;\n");
fprintf(dat, "ucpx = ucpx+busep+ucw; ucw = buw-busep-ucw-busep-(buw-2*busep)/3;\n");
fprintf(dat, "uc_xf = uicontrol('Style', 'edit', 'Callback', {@cbf_xfld}, ...\n");
fprintf(dat, "                  'String', num2str(chx), 'Min', 1, 'Max', 1, ...\n");
fprintf(dat, "                  'TooltipString', 'View & set x-position', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                  'BackgroundColor', col_abg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: horizontal cross section\n");
fprintf(dat, "ucpx = ucpx+busep+ucw; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_hc = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_crosssec, 'h'}, ...\n");
fprintf(dat, "                  'String', '---', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Horizontal field section', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: refractive index profile\n");
fprintf(dat, "ucw = (buw-2*busep)/3; ucpx = bupx+2*ucw+2*busep; ucpy = ucpy+uch+busep;\n");
fprintf(dat, "uc_n  = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_npl}, ...\n");
fprintf(dat, "                  'String', 'n', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Refractive index profile', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Sx-profile \n");
fprintf(dat, "ucpx = bupx; ucpy = ucpy+uch+10*busep; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_sx = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_sxpl}, ...\n");
fprintf(dat, "                  'String', 'Sx', 'FontSize', fntsz, ...\n");
fprintf(dat, "            'TooltipString', 'Time-averaged Poynting vector, x-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Sz-profile \n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_sz = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_szpl}, ...\n");
fprintf(dat, "                  'String', 'Sz', 'FontSize', fntsz, ...\n");
fprintf(dat, "            'TooltipString', 'Time-averaged Poynting vector, z-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: w-profile \n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_w  = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_wpl}, ...\n");
fprintf(dat, "                  'String', 'w', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Energy density of the optical field', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: field-profile \n");
fprintf(dat, "ucpx = bupx; ucpy = ucpy+uch+busep; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_f  = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_fldpl}, ...\n");
fprintf(dat, "                  'String', 'F', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'The physical field, time snapshot', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: profile of the absolute field value\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_fm = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_fldmpl}, ...\n");
fprintf(dat, "                  'String', '|F|', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Absolute value of the complex field', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: profile of the absolute field square \n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_fq = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_fldqpl}, ...\n");
fprintf(dat, "                  'String', '|F|^2', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Absolute square of the complex field', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Annotations, slider time position\n");
fprintf(dat, "ucpy = ucpy+uch+busep; uch = uch0; ucw = buw/3; ucpx = bupx;\n");
fprintf(dat, "uc_tll = uicontrol('Style', 'text', 'String', 't=0 ...', ...\n");
fprintf(dat, "                   'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                   'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                   'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "ucpx = ucpx+ucw;\n");
fprintf(dat, "uc_tlc = uicontrol('Style', 'text', 'String', 'T/2', ...\n");
fprintf(dat, "                   'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                   'FontSize', fntsz, 'HorizontalAlignment', 'center', ...\n");
fprintf(dat, "                   'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "ucpx = ucpx+ucw;\n");
fprintf(dat, "uc_tlc = uicontrol('Style', 'text', 'String', '... T ', ...\n");
fprintf(dat, "                   'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                   'FontSize', fntsz, 'HorizontalAlignment', 'right', ...\n");
fprintf(dat, "                   'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Slider: field snapshot time \n");
fprintf(dat, "global uc_tp;\n");
fprintf(dat, "ucpy = ucpy+uch+busep; uch = uch0*3/4; ucw = buw; ucpx = bupx;\n");
fprintf(dat, "uc_tp = uicontrol('Style', 'slider', 'Callback', {@cbf_timep}, ...\n");
fprintf(dat, "                  'Max', 1.0, 'Min', 0.0, 'Value', 0.0, ...\n");
fprintf(dat, "      'TooltipString', 'Physical field, snapshot time within one period T', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: play reverse animation\n");
fprintf(dat, "ucpy = ucpy+uch+busep; uch = uch0; ucpx = bupx; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_anbw = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_play, 'b'}, ...\n");
fprintf(dat, "                    'String', '<<', 'FontSize', fntsz, ...\n");
fprintf(dat, "                    'TooltipString', 'Backward wave propagation', ...\n");
fprintf(dat, "                    'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                    'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Input field: numer of time periods shown in the animation\n");
fprintf(dat, "global uc_annp; ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_annp = uicontrol('Style', 'edit', 'Callback', {@cbf_annp}, ...\n");
fprintf(dat, "                    'String', num2str(an_nump), 'Min', 1, 'Max', 1, ...\n");
fprintf(dat, "                    'TooltipString', 'Runtime/T of the animation', ...\n");
fprintf(dat, "                    'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                    'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                    'BackgroundColor', col_abg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: play field animation\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_anfw = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_play, 'f'}, ...\n");
fprintf(dat, "                    'String', '>>', 'FontSize', fntsz, ...\n");
fprintf(dat, "                    'TooltipString', 'Forward wave propagation', ...\n");
fprintf(dat, "                    'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                    'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Hx-component\n");
fprintf(dat, "ucpy = ucpy+uch+10*busep; uch = uch0; ucpx = bupx; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_hx = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_hxpl}, ...\n");
fprintf(dat, "                  'String', 'Hx', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Magnetic field, x-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Hy-component\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_hy = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_hypl}, ...\n");
fprintf(dat, "                  'String', 'Hy', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Magnetic field, y-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Hz-component\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_hz = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_hzpl}, ...\n");
fprintf(dat, "                  'String', 'Hz', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Magnetic field, z-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Ex-component\n");
fprintf(dat, "ucpx = bupx; ucpy = ucpy+uch+busep; ucw = (buw-2*busep)/3;\n");
fprintf(dat, "uc_ex = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_expl}, ...\n");
fprintf(dat, "                  'String', 'Ex', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Electric field, x-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Ey-component\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_ey = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_eypl}, ...\n");
fprintf(dat, "                  'String', 'Ey', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Electric field, y-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Button: Ey-component\n");
fprintf(dat, "ucpx = ucpx+busep+ucw;\n");
fprintf(dat, "uc_ez = uicontrol('Style', 'pushbutton', 'Callback', {@cbf_ezpl}, ...\n");
fprintf(dat, "                  'String', 'Ez', 'FontSize', fntsz, ...\n");
fprintf(dat, "                  'TooltipString', 'Electric field, z-component', ...\n");
fprintf(dat, "                  'Units', 'normalized', 'Position', [ucpx ucpy ucw uch], ...\n");
fprintf(dat, "                  'BackgroundColor', col_but, 'ForegroundColor', col_btx);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Annotation: polarization and wavelength\n");
fprintf(dat, "uch = uch0; ucpy = axpy+axh-uch; ucpx = bupx;\n");
fprintf(dat, "uc_an = uicontrol('Style', 'text', 'Units', 'normalized', ...\n");
fprintf(dat, "                  'String', [pol ', ' num2str(lambda) ' um'], ...\n");
fprintf(dat, "                  'FontSize', fntsz, 'HorizontalAlignment', 'left', ...\n");
fprintf(dat, "                  'BackgroundColor', col_fbg, 'ForegroundColor', col_txt);\n");
fprintf(dat, "p = get(uc_an, 'Extent'); ucw = p(3);\n");
fprintf(dat, "set(uc_an, 'Position', [ucpx ucpy ucw uch]);\n");
fprintf(dat, "\n");
fprintf(dat, "%% -------------------------------------------------------------------------\n");
fprintf(dat, "%% Callback functions for the gui objects \n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: input z-coordinate \n");
fprintf(dat, "function cbf_zfld(obj, eventdata)\n");
fprintf(dat, "global uc_zf chz chv zbeg zend;\n");
fprintf(dat, "chz = str2double(get(uc_zf, 'String'));\n");
fprintf(dat, "if isnan(chz) chz = 0.5*(zbeg+zend); end\n");
fprintf(dat, "if chz<zbeg chz = zbeg; end\n");
fprintf(dat, "if chz>zend chz = zend; end\n");
fprintf(dat, "set(chv, 'XData', [chz chz]); \n");
fprintf(dat, "set(uc_zf, 'String', num2str(chz)); \n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: input x-coordinate \n");
fprintf(dat, "function cbf_xfld(obj, eventdata)\n");
fprintf(dat, "global uc_xf chx chh xbeg xend;\n");
fprintf(dat, "chx = str2double(get(uc_xf, 'String'));\n");
fprintf(dat, "if isnan(chx) chx = 0.5*(xbeg+xend); end\n");
fprintf(dat, "if chx<xbeg chx = xbeg; end\n");
fprintf(dat, "if chx>xend chx = xend; end\n");
fprintf(dat, "set(chh, 'YData', [chx chx]); \n");
fprintf(dat, "set(uc_xf, 'String', num2str(chx)); \n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Sx \n");
fprintf(dat, "function cbf_sxpl(obj, eventdata)\n");
fprintf(dat, "global Sx max_S pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Sx; pl_fldim = Sx*0.0; pl_cp = 'S_x';\n");
fprintf(dat, "pl_min = -max_S; pl_max = max_S;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Sz \n");
fprintf(dat, "function cbf_szpl(obj, eventdata)\n");
fprintf(dat, "global Sz max_S pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Sz; pl_fldim = Sz*0; pl_cp = 'S_z';\n");
fprintf(dat, "pl_min = -max_S; pl_max = max_S;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select w \n");
fprintf(dat, "function cbf_wpl(obj, eventdata)\n");
fprintf(dat, "global W max_W pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = W; pl_fldim = W*0; pl_cp = 'w'; pl_min = 0.0; pl_max = max_W;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select physical field \n");
fprintf(dat, "function cbf_fldpl(obj, eventdata)\n");
fprintf(dat, "global pl_afo;\n");
fprintf(dat, "pl_afo = 'f'; \n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select absolute field value\n");
fprintf(dat, "function cbf_fldmpl(obj, eventdata)\n");
fprintf(dat, "global pl_afo;\n");
fprintf(dat, "pl_afo = 'm'; \n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select absolute field square \n");
fprintf(dat, "function cbf_fldqpl(obj, eventdata)\n");
fprintf(dat, "global pl_afo;\n");
fprintf(dat, "pl_afo = 'q'; \n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select adjust snapshot time \n");
fprintf(dat, "function cbf_timep(obj, eventdata)\n");
fprintf(dat, "global uc_tp pl_tp;\n");
fprintf(dat, "pl_tp = get(uc_tp, 'Value');\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select animation runtime \n");
fprintf(dat, "function cbf_annp(obj, eventdata)\n");
fprintf(dat, "global uc_annp an_nump;\n");
fprintf(dat, "np = str2double(get(uc_annp, 'String'));\n");
fprintf(dat, "if isnan(np) np = 10; end\n");
fprintf(dat, "if np<1  np = 1;  end\n");
fprintf(dat, "if np>99 np = 99; end\n");
fprintf(dat, "an_nump = round(np);\n");
fprintf(dat, "set(uc_annp, 'String', num2str(an_nump)); \n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Hx \n");
fprintf(dat, "function cbf_hxpl(obj, eventdata)\n");
fprintf(dat, "global Hx_re Hx_im max_H pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Hx_re; pl_fldim = Hx_im; pl_cp = 'H_x';\n");
fprintf(dat, "pl_min = -max_H; pl_max = max_H;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Hy \n");
fprintf(dat, "function cbf_hypl(obj, eventdata)\n");
fprintf(dat, "global Hy_re Hy_im max_H pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Hy_re; pl_fldim = Hy_im; pl_cp = 'H_y';\n");
fprintf(dat, "pl_min = -max_H; pl_max = max_H;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Hz \n");
fprintf(dat, "function cbf_hzpl(obj, eventdata)\n");
fprintf(dat, "global Hz_re Hz_im max_H pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Hz_re; pl_fldim = Hz_im; pl_cp = 'H_z';\n");
fprintf(dat, "pl_min = -max_H; pl_max = max_H;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Ex \n");
fprintf(dat, "function cbf_expl(obj, eventdata)\n");
fprintf(dat, "global Ex_re Ex_im max_E pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Ex_re; pl_fldim = Ex_im; pl_cp = 'E_x';\n");
fprintf(dat, "pl_min = -max_E; pl_max = max_E;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Ey \n");
fprintf(dat, "function cbf_eypl(obj, eventdata)\n");
fprintf(dat, "global Ey_re Ey_im max_E pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Ey_re; pl_fldim = Ey_im; pl_cp = 'E_y';\n");
fprintf(dat, "pl_min = -max_E; pl_max = max_E;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select Ez \n");
fprintf(dat, "function cbf_ezpl(obj, eventdata)\n");
fprintf(dat, "global Ez_re Ez_im max_E pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = Ez_re; pl_fldim = Ez_im; pl_cp = 'E_z';\n");
fprintf(dat, "pl_min = -max_E; pl_max = max_E;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: select n\n");
fprintf(dat, "function cbf_npl(obj, eventdata)\n");
fprintf(dat, "global n min_n max_n pl_fldre pl_fldim pl_min pl_max pl_cp;\n");
fprintf(dat, "pl_fldre = n; pl_fldim = n*0.0; pl_cp = 'n'; pl_min = min_n; pl_max = max_n;\n");
fprintf(dat, "if pl_min>=pl_max pl_min = pl_min-0.5; pl_max = pl_min+1.0; end;\n");
fprintf(dat, "d = (pl_max-pl_min)/3; pl_min = pl_min-d; pl_max = pl_max+d;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% -------------------------------------------------------------------------\n");
fprintf(dat, "%% The actual plotting routines, partly callbacks for gui objects\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: crosshair positioning \n");
fprintf(dat, "function clbf_crossh(obj, eventdata)\n");
fprintf(dat, "global fgr axs chh chv chx chz;\n");
fprintf(dat, "mpos = get(0, 'PointerLocation'); \n");
fprintf(dat, "mx=mpos(1); my=mpos(2);\n");
fprintf(dat, "fpos = get(fgr, 'Position'); fx=fpos(1); fy=fpos(2); fw=fpos(3); fh=fpos(4); \n");
fprintf(dat, "rx = (mx-fx)/fw; ry = (my-fy)/fh;\n");
fprintf(dat, "apos = get(axs, 'Position'); ax=apos(1); ay=apos(2); aw=apos(3); ah=apos(4); \n");
fprintf(dat, "extx = get(axs, 'Xlim'); x0=extx(1); x1=extx(2);\n");
fprintf(dat, "exty = get(axs, 'Ylim'); y0=exty(1); y1=exty(2);\n");
fprintf(dat, "px = x0+(rx-ax)/aw*(x1-x0); py = y0+(ry-ay)/ah*(y1-y0);\n");
fprintf(dat, "chx = py; chz = px;\n");
fprintf(dat, "global xbeg xend zbeg zend;\n");
fprintf(dat, "if chx<xbeg chx = xbeg; end\n");
fprintf(dat, "if chx>xend chx = xend; end\n");
fprintf(dat, "if chz<zbeg chz = zbeg; end\n");
fprintf(dat, "if chz>zend chz = zend; end\n");
fprintf(dat, "set(chh, 'YData', [chx chx]); set(chv, 'XData', [chz chz]); \n");
fprintf(dat, "global uc_xf uc_zf;\n");
fprintf(dat, "set(uc_xf, 'String', num2str(chx)); set(uc_zf, 'String', num2str(chz)); \n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: place contour line\n");
fprintf(dat, "function clbf_contour(obj, eventdata)\n");
fprintf(dat, "global fgr axs clb cont_ah cont_num cont_hdl;\n");
fprintf(dat, "for k=1:cont_num delete(cont_hdl(k)); end\n");
fprintf(dat, "mpos = get(0, 'PointerLocation'); my=mpos(2);\n");
fprintf(dat, "fpos = get(fgr, 'Position'); fy=fpos(2); fh=fpos(4); \n");
fprintf(dat, "ry = (my-fy)/fh;\n");
fprintf(dat, "apos = get(clb, 'Position'); ay=apos(2); ah=apos(4); \n");
fprintf(dat, "exty = get(clb, 'Ylim'); y0=exty(1); y1=exty(2);\n");
fprintf(dat, "lv = y0+(ry-ay)/ah*(y1-y0); \n");
fprintf(dat, "global pl_amin pl_amax;\n");
fprintf(dat, "if lv<pl_amin lv = pl_amin; end\n");
fprintf(dat, "if lv>pl_amax lv = pl_amax; end\n");
fprintf(dat, "set(cont_ah, 'YData', [lv lv]); \n");
fprintf(dat, "axes(axs); hold on;\n");
fprintf(dat, "global z x pl_fld;\n");
fprintf(dat, "cm = contourc(z, x, pl_fld, [lv, lv]); cl = size(cm, 2);\n");
fprintf(dat, "k = 1; cont_hdl = ones(1, cl); cont_num = 0;\n");
fprintf(dat, "while(k < cl)\n");
fprintf(dat, "      np = cm(2, k); pz = cm(1, k+1:k+np); px = cm(2, k+1:k+np);\n");
fprintf(dat, "      cont_num = cont_num+1;\n");
fprintf(dat, "      cont_hdl(cont_num) = line(pz, px, ...\n");
fprintf(dat, "                          'Color', 'b', 'LineStyle', '-', 'LineWidth', 0.5, ...\n");
fprintf(dat, "                          'ButtonDownFcn', {@clbf_crossh});\n");
fprintf(dat, "      k = k+np+1;\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: update the field plot \n");
fprintf(dat, "function updateplot\n");
fprintf(dat, "global fgr axs tle clb clb_img;\n");
fprintf(dat, "global pl_fld pl_fldre pl_fldim pl_tp pl_min pl_max pl_amin pl_amax;\n");
fprintf(dat, "global pl_cp pl_img pl_afo pl_tih;\n");
fprintf(dat, "global x z;\n");
fprintf(dat, "global cont_ah cont_minh cont_maxh cont_num cont_hdl;\n");
fprintf(dat, "global mag_blue lin_blue;\n");
fprintf(dat, "for k=1:cont_num delete(cont_hdl(k)); end\n");
fprintf(dat, "cont_num = 0;\n");
fprintf(dat, "switch pl_cp\n");
fprintf(dat, "case {'E_x', 'E_y', 'E_z', 'H_x', 'H_y', 'H_z'} \n");
fprintf(dat, "   if pl_afo == 'm' \n");
fprintf(dat, "      title = ['| ' pl_cp '(x, z) |']; \n");
fprintf(dat, "      pl_fld = sqrt(pl_fldre.*pl_fldre+pl_fldim.*pl_fldim);\n");
fprintf(dat, "      clm = lin_blue; minlv = 0.0; maxlv = pl_max;\n");
fprintf(dat, "      set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "   elseif pl_afo == 'q'\n");
fprintf(dat, "      title = ['| ' pl_cp '(x, z) |^2']; \n");
fprintf(dat, "      pl_fld = pl_fldre.*pl_fldre+pl_fldim.*pl_fldim;\n");
fprintf(dat, "      clm = lin_blue; minlv = 0.0; maxlv = pl_max*pl_max;\n");
fprintf(dat, "      set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "   else\n");
fprintf(dat, "      title = ['Re ' pl_cp '(x, z) e^{i 2 \\pi t / T}'];\n");
fprintf(dat, "      pl_fld = pl_fldre*cos(2*pi*pl_tp)-pl_fldim*sin(2*pi*pl_tp);\n");
fprintf(dat, "      clm = mag_blue; minlv = -pl_max; maxlv = pl_max;\n");
fprintf(dat, "      set(pl_tih, 'Visible', 'on', 'String', sprintf('t = %%#4.2f T', pl_tp));\n");
fprintf(dat, "   end\n");
fprintf(dat, "case {'S_x', 'S_z'}\n");
fprintf(dat, "   if pl_afo == 'm' || pl_afo == 'q'\n");
fprintf(dat, "      title = ['| ' pl_cp '(x, z) |']; \n");
fprintf(dat, "      pl_fld = sqrt(pl_fldre.*pl_fldre);\n");
fprintf(dat, "      clm = lin_blue; minlv = 0.0; maxlv = pl_max;\n");
fprintf(dat, "      set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "   else\n");
fprintf(dat, "      title = [pl_cp '(x, z)'];\n");
fprintf(dat, "      pl_fld = pl_fldre;\n");
fprintf(dat, "      clm = mag_blue; minlv = -pl_max; maxlv = pl_max;\n");
fprintf(dat, "      set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "   end\n");
fprintf(dat, "case {'w'}\n");
fprintf(dat, "   title = 'w(x, z)';\n");
fprintf(dat, "   pl_fld = pl_fldre;\n");
fprintf(dat, "   clm = lin_blue; minlv = 0.0; maxlv = pl_max;\n");
fprintf(dat, "   set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "case {'n'}\n");
fprintf(dat, "   title = 'n(x, z)';\n");
fprintf(dat, "   pl_fld = pl_fldre;\n");
fprintf(dat, "   clm = lin_blue; minlv = pl_min; maxlv = pl_max;\n");
fprintf(dat, "   set(pl_tih, 'Visible', 'off');\n");
fprintf(dat, "end\n");
fprintf(dat, "pl_amin = min(min(pl_fld)); pl_amax = max(max(pl_fld));\n");
fprintf(dat, "set(fgr, 'Colormap', clm);\n");
fprintf(dat, "set(clb_img, 'CData', linspace(minlv, maxlv, 64)', ...\n");
fprintf(dat, "             'YData', linspace(minlv, maxlv, 64)');\n");
fprintf(dat, "set(clb, 'YLim', [minlv, maxlv], 'CLim', [minlv, maxlv]);\n");
fprintf(dat, "set(cont_ah, 'YData', [minlv minlv]); \n");
fprintf(dat, "set(cont_minh, 'YData', [pl_amin pl_amin]); \n");
fprintf(dat, "set(cont_maxh, 'YData', [pl_amax pl_amax]); \n");
fprintf(dat, "set(tle, 'String', title);\n");
fprintf(dat, "set(axs, 'CLim', [minlv, maxlv]);\n");
fprintf(dat, "set(pl_img, 'CData', pl_fld);\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: field animation \n");
fprintf(dat, "function cbf_play(obj, eventdata, dr) \n");
fprintf(dat, "global fgr axs tle clb clb_img uc_tp mag_blue lin_blue;\n");
fprintf(dat, "global pl_fld pl_fldre pl_fldim pl_tp pl_min pl_max x z;\n");
fprintf(dat, "global pl_cp pl_img pl_afo pl_tih an_nump;\n");
fprintf(dat, "global cont_ah cont_num cont_hdl;\n");
fprintf(dat, "for k=1:cont_num delete(cont_hdl(k)); end\n");
fprintf(dat, "cont_num = 0;\n");
fprintf(dat, "switch pl_cp\n");
fprintf(dat, "case {'E_x', 'E_y', 'E_z', 'H_x', 'H_y', 'H_z'} \n");
fprintf(dat, "   if pl_afo == 'm' | pl_afo =='q' return; end\n");
fprintf(dat, "case {'S_x', 'S_z', 'w', 'n'}\n");
fprintf(dat, "   return;\n");
fprintf(dat, "end\n");
fprintf(dat, "clm = mag_blue;\n");
fprintf(dat, "minlv = -pl_max; maxlv = pl_max;\n");
fprintf(dat, "set(fgr, 'Colormap', clm);\n");
fprintf(dat, "set(clb_img, 'CData', linspace(minlv, maxlv, 64)', ...\n");
fprintf(dat, "             'YData', linspace(minlv, maxlv, 64)');\n");
fprintf(dat, "set(clb, 'YLim', [minlv, maxlv], 'CLim', [minlv, maxlv]);\n");
fprintf(dat, "set(cont_ah, 'YData', [minlv minlv]); \n");
fprintf(dat, "set(axs, 'CLim', [minlv, maxlv]);\n");
fprintf(dat, "title = ['Re ' pl_cp '(x, z) e^{i 2 \\pi t / T}'];\n");
fprintf(dat, "set(tle, 'String', title);\n");
fprintf(dat, "set(pl_tih, 'Visible', 'on', 'String', sprintf('t = %%#4.2f T', pl_tp));\n");
fprintf(dat, "axes(axs);\n");
fprintf(dat, "msp = moviein(30);\n");
fprintf(dat, "for ti=0:29\n");
fprintf(dat, "   if dr == 'b'\n");
fprintf(dat, "      t = pl_tp-ti/30; if t<0 t = 1+t; end\n");
fprintf(dat, "   else \n");
fprintf(dat, "      t = pl_tp+ti/30; if t>1 t = t-1; end\n");
fprintf(dat, "   end\n");
fprintf(dat, "   pl_fld = pl_fldre*cos(2*pi*t)-pl_fldim*sin(2*pi*t);\n");
fprintf(dat, "   set(pl_img, 'CData', pl_fld);\n");
fprintf(dat, "   set(pl_tih, 'String', sprintf('t = %%#4.2f T', t));\n");
fprintf(dat, "   set(uc_tp, 'Value', t);\n");
fprintf(dat, "   msp(:,ti+1) = getframe;\n");
fprintf(dat, "end\n");
fprintf(dat, "set(uc_tp, 'Value', pl_tp);\n");
fprintf(dat, "movie(msp, an_nump-1);\n");
fprintf(dat, "title = ['Re ' pl_cp '(x, z) e^{i 2 \\pi t / T}'];\n");
fprintf(dat, "set(tle, 'String', title);\n");
fprintf(dat, "pl_fld = pl_fldre*cos(2*pi*(pl_tp+t))-pl_fldim*sin(2*pi*(pl_tp+t));\n");
fprintf(dat, "set(pl_img, 'CData', pl_fld);\n");
fprintf(dat, "set(pl_tih, 'String', sprintf('t = %%#4.2f T', pl_tp));\n");
fprintf(dat, "clear msp;\n");
fprintf(dat, "updateplot;\n");
fprintf(dat, "\n");
fprintf(dat, "%% Callback: cross section figure\n");
fprintf(dat, "function cbf_crosssec(obj, eventdata, dr)\n");
fprintf(dat, "global csf_xaw csf_zaw;\n");
fprintf(dat, "global col_fbg col_txt col_abg col_atx fntsz fgr;\n");
fprintf(dat, "global x z xbeg xend zbeg zend numx numz;\n");
fprintf(dat, "global chx chz pl_fld pl_cp pl_afo pl_tp pl_min pl_max; \n");
fprintf(dat, "csf = figure('NumberTitle', 'off', 'Name', 'fldxyA, field section', ...\n");
fprintf(dat, "             'Color', col_fbg, 'Units', 'pixels', 'Menubar', 'none');\n");
fprintf(dat, "if dr == 'h' axw = csf_zaw; else axw = csf_xaw; end\n");
fprintf(dat, "axh = 200; fgw = axw+60+20; fgh = axh+40+20;\n");
fprintf(dat, "axw = axw/fgw; axh = axh/fgh; axpx = 60/fgw; axpy = 40/fgh;\n");
fprintf(dat, "scrsz = get(0, 'ScreenSize');\n");
fprintf(dat, "if fgw > scrsz(3)*0.6 \n");
fprintf(dat, "   s = scrsz(3)*0.6/fgw; fgw = fgw*s; fgh = fgh*s;\n");
fprintf(dat, "end\n");
fprintf(dat, "if fgh > scrsz(4)*0.6 \n");
fprintf(dat, "   s = scrsz(4)*0.6/fgh; fgw = fgw*s; fgh = fgh*s;\n");
fprintf(dat, "end\n");
fprintf(dat, "fgpx = round(scrsz(1)+scrsz(3)*0.1); fgpy = round(scrsz(2)+scrsz(4)*0.90)-fgh;\n");
fprintf(dat, "p = get(fgr, 'Position');\n");
fprintf(dat, "if p(1)+p(3)+fgw+10 <= scrsz(1)+scrsz(3) \n");
fprintf(dat, "   fgpx = p(1)+p(3)+10; fgpy = p(2);\n");
fprintf(dat, "end\n");
fprintf(dat, "set(csf, 'Position', [fgpx fgpy fgw fgh]);\n");
fprintf(dat, "csf_axs = axes;\n");
fprintf(dat, "axes(csf_axs); hold on; box on;\n");
fprintf(dat, "set(csf_axs, 'Position', [axpx axpy axw axh], 'Units', 'normalized', ...\n");
fprintf(dat, "             'YDir', 'normal', 'TickDir', 'out', 'FontSize', fntsz);\n");
fprintf(dat, "if dr == 'h'\n");
fprintf(dat, "   xlabel('z [\\mum]', 'FontSize', fntsz);\n");
fprintf(dat, "   cbeg = zbeg; cend = zend; cod = z;\n");
fprintf(dat, "   poss = sprintf('x = %%.5g \\\\mum', chx);\n");
fprintf(dat, "else \n");
fprintf(dat, "   xlabel('x [\\mum]', 'FontSize', fntsz);\n");
fprintf(dat, "   cbeg = xbeg; cend = xend; cod = x;\n");
fprintf(dat, "   poss = sprintf('z = %%.5g \\\\mum', chz);\n");
fprintf(dat, "end\n");
fprintf(dat, "set(csf_axs, 'XLim', [cbeg, cend]);\n");
fprintf(dat, "coc = linspace(cbeg, cend, 1000);\n");
fprintf(dat, "if dr == 'h'\n");
fprintf(dat, "   fldicoc = interp2(z, x, pl_fld, coc, linspace(chx, chx, 1000), 'linear');\n");
fprintf(dat, "   fldicod = interp2(z, x, pl_fld, cod, linspace(chx, chx, length(z)));\n");
fprintf(dat, "else\n");
fprintf(dat, "   fldicoc = interp2(z, x, pl_fld, linspace(chz, chz, 1000), coc, 'linear');\n");
fprintf(dat, "   fldicod = interp2(z, x, pl_fld, linspace(chz, chz, length(x)), cod);\n");
fprintf(dat, "end\n");
fprintf(dat, "switch pl_cp\n");
fprintf(dat, "case {'E_x', 'E_y', 'E_z', 'H_x', 'H_y', 'H_z'} \n");
fprintf(dat, "   if pl_afo == 'm' \n");
fprintf(dat, "      ylabel(['| ' pl_cp ' |'], 'FontSize', fntsz);\n");
fprintf(dat, "      fbeg = 0.0; fend = pl_max;\n");
fprintf(dat, "   elseif pl_afo == 'q'\n");
fprintf(dat, "      ylabel(['| ' pl_cp ' |^2'], 'FontSize', fntsz);\n");
fprintf(dat, "      fbeg = 0.0; fend = pl_max*pl_max;\n");
fprintf(dat, "   else\n");
fprintf(dat, "      ylabel(['Re ' pl_cp ' e^{i 2 \\pi t / T}'], 'FontSize', fntsz);\n");
fprintf(dat, "      fbeg = -pl_max; fend = pl_max;\n");
fprintf(dat, "      poss = [poss, sprintf(',  t = %%#4.2f T', pl_tp)];\n");
fprintf(dat, "   end\n");
fprintf(dat, "case {'S_x', 'S_z'}\n");
fprintf(dat, "   if pl_afo == 'm' || pl_afo == 'q'\n");
fprintf(dat, "      ylabel(['| ' pl_cp ' |'], 'FontSize', fntsz);\n");
fprintf(dat, "      fbeg = 0.0; fend = pl_max;\n");
fprintf(dat, "   else\n");
fprintf(dat, "      ylabel(pl_cp, 'FontSize', fntsz);\n");
fprintf(dat, "      fbeg = -pl_max; fend = pl_max;\n");
fprintf(dat, "   end\n");
fprintf(dat, "case {'w'}\n");
fprintf(dat, "   ylabel('w', 'FontSize', fntsz);\n");
fprintf(dat, "   fbeg = 0.0; fend = pl_max;\n");
fprintf(dat, "case {'n'}\n");
fprintf(dat, "   ylabel('n', 'FontSize', fntsz);\n");
fprintf(dat, "   fbeg = pl_min; fend = pl_max;\n");
fprintf(dat, "end\n");
fprintf(dat, "global Rc Ri w_i g_i w_o g_o n min_n max_n ; \n");
fprintf(dat, "if dr == 'h'\n");
fprintf(dat, "   cb = ones(4); ncb = 0;\n");
fprintf(dat, "   if chx<Rc && chx>-Rc\n");
fprintf(dat, "      rczp = sqrt(Rc*Rc-chx*chx);\n");
fprintf(dat, "      ncb = ncb+1; cb(ncb) = -rczp;\n");
fprintf(dat, "      if chx<Ri && chx>-Ri\n");
fprintf(dat, "         rizp = sqrt(Ri*Ri-chx*chx);\n");
fprintf(dat, "         ncb = ncb+1; cb(ncb) = -rizp;\n");
fprintf(dat, "         ncb = ncb+1; cb(ncb) =  rizp;\n");
fprintf(dat, "      end\n");
fprintf(dat, "      ncb = ncb+1; cb(ncb) =  rczp;\n");
fprintf(dat, "   end\n");
fprintf(dat, "   for d=1:ncb+1\n");
fprintf(dat, "      if d==1     b0=cbeg; else b0=cb(d-1); end\n");
fprintf(dat, "      if d==ncb+1 b1=cend; else b1=cb(d);   end\n");
fprintf(dat, "      ri = interp2(z, x, n, 0.5*(b1+b0), chx);\n");
fprintf(dat, "      pc = 1.0-(ri-min_n)/(max_n-min_n)*0.2;\n");
fprintf(dat, "      patch([b0 b0 b1 b1], [fend fbeg fbeg fend], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "   end\n");
fprintf(dat, "else\n");
fprintf(dat, "   cb = ones(8); ncb = 0;\n");
fprintf(dat, "   ncb = ncb+1; cb(ncb) = -Rc-g_o-w_o;\n");
fprintf(dat, "   ncb = ncb+1; cb(ncb) = -Rc-g_o;\n");
fprintf(dat, "   if chz<Rc && chz>-Rc\n");
fprintf(dat, "      rcxp = sqrt(Rc*Rc-chz*chz);\n");
fprintf(dat, "      ncb = ncb+1; cb(ncb) = -rcxp;\n");
fprintf(dat, "      if chz<Ri && chz>-Ri\n");
fprintf(dat, "         rixp = sqrt(Ri*Ri-chz*chz);\n");
fprintf(dat, "         ncb = ncb+1; cb(ncb) = -rixp;\n");
fprintf(dat, "         ncb = ncb+1; cb(ncb) =  rixp;\n");
fprintf(dat, "      end\n");
fprintf(dat, "      ncb = ncb+1; cb(ncb) =  rcxp;\n");
fprintf(dat, "   end\n");
fprintf(dat, "   ncb = ncb+1; cb(ncb) = Rc+g_i;\n");
fprintf(dat, "   ncb = ncb+1; cb(ncb) = Rc+g_i+w_i;\n");
fprintf(dat, "   for d=1:ncb+1\n");
fprintf(dat, "      if d==1     b0=cbeg; else b0=cb(d-1); end\n");
fprintf(dat, "      if d==ncb+1 b1=cend; else b1=cb(d);   end\n");
fprintf(dat, "      ri = interp2(z, x, n, chz, 0.5*(b1+b0));\n");
fprintf(dat, "      pc = 1.0-(ri-min_n)/(max_n-min_n)*0.2;\n");
fprintf(dat, "      patch([b0 b0 b1 b1], [fend fbeg fbeg fend], [pc pc pc], ...\n");
fprintf(dat, "           'LineStyle', 'none');\n");
fprintf(dat, "   end\n");
fprintf(dat, "end\n");
fprintf(dat, "for d=1:ncb\n");
fprintf(dat, "   plot([cb(d), cb(d)], [fbeg fend], 'k-', 'LineWidth', 1);\n");
fprintf(dat, "end\n");
fprintf(dat, "text(cend-(cend-cbeg)/30, fend-(fend-fbeg)/30, ...\n");
fprintf(dat, "     poss, 'Color', 'k', 'HorizontalAlignment', 'right', ...\n");
fprintf(dat, "     'VerticalAlignment', 'top', 'FontSize', fntsz);\n");
fprintf(dat, "set(csf_axs, 'YLim', [fbeg, fend]);\n");
fprintf(dat, "plot(coc, fldicoc, 'b-', 'LineWidth', 2); \n");
fprintf(dat, "ms = 2; if length(cod) <= 60 ms = 4; end\n");
fprintf(dat, "plot(cod, fldicod, 'ko', 'MarkerSize', ms, 'LineWidth', 2); \n");
fprintf(dat, "plot([cbeg cbeg cend cend cbeg], [fend fbeg fbeg fend fend], 'k-');\n");
fprintf(dat, "\n");
}


//---------------------------------
/* waveguide geometry for bent-straight waveguide coupler */
void mlout_bscoupgeo(FILE *dat, BSlabWaveguide b, Waveguide s) 
{
        fprintf(dat, "%% bent-straight waveguide coupler geometry\n");
        fprintf(dat, "Rc = %g;\n", b.R+b.wg.hx(1));
	if(   fabs(b.wg.hx(1)-b.wg.hx(0))>COMPTOL_HX 
	   && fabs(b.wg.n(0)-b.wg.n(1))>COMPTOL_N)
	        fprintf(dat, "Ri = %g;\n", b.R+b.wg.hx(0));
	else 
	        fprintf(dat, "Ri = %g;\n", b.R+b.wg.hx(1));
        fprintf(dat, "w = %g;\n", s.hx(1)-s.hx(0));
//        fprintf(dat, "g = %g;\n", s.hx(0)-(b.R+b.wg.hx(0)));
	fprintf(dat, "g = %g;\n", s.hx(0)-(b.R+b.wg.hx(1)));
        fprintf(dat, "\n");

        return;
}


//-------------------------------------------------------
/* sketch of permittivity boundaries: outline the coupler geometry */
void mlout_coupgeooutline(FILE *dat)
{
        fprintf(dat, "plot([zbeg, zend], [Rc+g+w, Rc+g+w], ls, 'LineWidth', lw);\n");
        fprintf(dat, "plot([zbeg, zend], [Rc+g, Rc+g], ls, 'LineWidth', lw);\n");

        fprintf(dat, "phi = linspace(0, 2*pi, 500);\n");
        fprintf(dat, "lcx = Rc*cos(phi); lcz = Rc*sin(phi);\n");
        fprintf(dat, "plot(lcz, lcx, ls, 'LineWidth', lw);\n");
        fprintf(dat, "lcx = Ri*cos(phi); lcz = Ri*sin(phi);\n");
        fprintf(dat, "plot(lcz, lcx, ls, 'LineWidth', lw);\n");
        fprintf(dat, "\n");
        return;
}

//-----------------------------------------------------------------
/* interference plot, b-s coupler structure */
void mlout_coupgenimage(Fcomp cp, char *name, char *desc, FILE *dat)
{
fprintf(dat, "%% Initialize the plot\n");
fprintf(dat, "figure('NumberTitle', 'off', 'Name', '%s,  %s(x, z)', 'Color', 'w');\n", name, desc);
fprintf(dat, "view(2);\n");
fprintf(dat, "\n");
fprintf(dat, "%% adjust intensity range to actual field\n");
fprintf(dat, "maxf = max(max(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "minf = min(min(%c%c));\n", fldchr(cp), cpchr(cp));
fprintf(dat, "if minf >= maxf\n");
fprintf(dat, "   minf = minf-1.0;\n");
fprintf(dat, "   maxf = minf+2.0;\n");
fprintf(dat, "end\n");
fprintf(dat, "\n");
fprintf(dat, "%% Intensity image\n");
fprintf(dat, "imagesc(z, x, %c%c, [minf, maxf]);\n", fldchr(cp), cpchr(cp)); 
fprintf(dat, "\n");
	mlout_contours(cp, dat);
fprintf(dat, "%% Adjust axes and labels\n");
fprintf(dat, "box on;\n");
fprintf(dat, "axis([zbeg, zend, xbeg, xend]);\n");
fprintf(dat, "set(gca, 'FontSize', 24, ...\n");
fprintf(dat, "         'LineWidth', 2.0, ...\n");
fprintf(dat, "         'Clipping', 'off', ...\n");
fprintf(dat, "         'YDir', 'normal', ...\n");
fprintf(dat, "         'TickDir', 'out', ...\n");
fprintf(dat, "         'PlotBoxAspectRatio', [(zend-zbeg)/(xend-xbeg) 0.95 0.95]);\n");
fprintf(dat, "xlabel('z [\\mum]', 'FontSize', 24);\n");
fprintf(dat, "ylabel('x [\\mum]', 'FontSize', 24);\n");
fprintf(dat, "\n");
	mlout_sketchinit(dat);
	mlout_coupgeooutline(dat);
	return;
}
