/*
 * Circurs - Circular optical microresonators simulation tools
 * Kirankumar R. Hiremath (k.r.hiremath@ieee.org)
 * University of Twente, Department of Applied Mathematics 
 * P.O. Box 217, 7500AE Enschede, The Netherlands
 * (2005)
 */

/*
 * bslamvis.h
 * 1-D bend specific output to MATLAB .m -files, visualization  
 * helper routines for bslamode.c, bslamarr.c
 */

#ifndef BSLAMVIS_H
#define BSLAMVIS_H

#include "gengwed.h"

/* mode section plot, plot commands */
void mlout_Lsecplot_rad(char *name, FILE *dat, Fcomp cp, int nbd, int nsec);

/* mode section plot; combined re, im, abs, plot commands */
void mlout_bendriaplot(char *name, FILE *dat, double minf, double maxf,
                       Fcomp cp, int nbd, int nsec);

/* mode section plot; combined abs, phase, plot commands */
void mlout_bendaphplot(char *name, FILE *dat, double minf, double maxf,
                       Fcomp cp, int nbd, int nsec);

/* bend waveguide: geometry for interference visualization */
void mlout_bendgeoxz(FILE *dat, BSlabWaveguide bend, 
                    double xbeg, double xend, double zbeg, double zend);

/* sketch of permittivity boundaries: outline the geometry, bend waveguide */
void mlout_bendgeooutline(FILE *dat);

/* interference plot, bend waveguide */
void mlout_bendimage(Fcomp cp, char *name, FILE *dat);

/* interference animation, bend waveguide */
void mlout_bendmovie(Fcomp cp, char *name, FILE *dat, int ntfr, double dt,
                     double om, double famp);

/* ------------------------------------------------------------------- */
/* microresonator field plots, helper functions */

/* waveguide geometry and field extrema */
void mlout_micresgeo(FILE *dat, BSlabWaveguide b, Waveguide si, Waveguide so);

/* sketch of permittivity boundaries: outline the resonator geometry */
void mlout_micresgeooutline(FILE *dat);

/* interference plot, microresonator structure */
void mlout_micresgenimage(Fcomp cp, char *name, char *desc, FILE *dat);

/* interference animation, microresonator structure */
void mlout_micresmovie(Fcomp cp, char *name, char *desc, FILE *dat, 
                       int ntfr, double dt, double om, double famp);

/* field viewer .m-file: viewer commands, microresonator geometry */
void mlout_micresfldviewer(FILE *dat, char *name);

/* field viewer .m-file: top, title and globals */
void mlout_micresviewertop(FILE *dat, char *name, 
                           Polarization p, double lambda);


//--------------------------------------------------------------
/* waveguide geometry for bent-straight waveguide coupler */
void mlout_bscoupgeo(FILE *dat, BSlabWaveguide b, Waveguide s) ;

/* sketch of permittivity boundaries: outline the coupler geometry */
void mlout_coupgeooutline(FILE *dat);

/* interference plot, b-s coupler structure */
void mlout_coupgenimage(Fcomp cp, char *name, char *desc, FILE *dat);

#endif  // BSLAMVIS_H
