/*
 * Circurs - Circular optical microresonators simulation tools
 * Kirankumar R. Hiremath (k.r.hiremath@ieee.org)
 * University of Twente, Department of Applied Mathematics 
 * P.O. Box 217, 7500AE Enschede, The Netherlands
 * (2005)
 */

/* 
 * blawaveg.c
 * bent slab waveguide definition 
 */

#include<stdio.h>
#include<stdlib.h>
#include<math.h>
#include"inout.h"
#include"complex.h"
#include"bslawaveg.h"

/* error message */
void bslawavegerror(char *m)
{
        fprintf(stderr, "\nERROR: BSlabWaveguide: %s.\n", m);
        exit(1);
}  

/* initialize */
BSlabWaveguide::BSlabWaveguide()
{
	wg = Waveguide();
	R = 100.0;
}

/* initialize */
BSlabWaveguide::BSlabWaveguide(int numx) 
{
	wg = Waveguide(numx);
	R = 100.0;
}

/* initialize */
BSlabWaveguide::BSlabWaveguide(Waveguide w, double r)
{
	wg = w;
	R = r;
}

BSlabWaveguide::BSlabWaveguide(int layer_,
		       Dvector Bhx_,
		       double lambda_, 
		       Dvector Bn_, 
		       double R_)
{
    wg=Waveguide( layer_, Bhx_, lambda_,  Bn_);
    R = R_;
}

/* output to FILE dat */
void BSlabWaveguide::write(FILE *dat)
{
	if(dat == stderr || dat == stdout)
	{
		fprintf(dat, "BSlabWaveguide:\n");
		wg.write(dat);
		fprintf(dat, "R: %g\n", R);
	}
	else
	{
		comment("BSlabWaveguide:", dat);
		wg.write(dat);
		comment("R", dat);
		fputdouble(R, dat);
	}
	return;
}

/* input from FILE dat */
void BSlabWaveguide::read(FILE *dat)
{
	if(dat == stderr || dat == stdout) 
	{
		bslawavegerror("read");
	}
	wg.read(dat);
	R = fgetdouble(dat);
	return;
}

/* permittivity at cartesian position (x,z) */
double BSlabWaveguide::eps(double x, double z)
{
    return eps(sqrt(x*x + z*z));
}

//permittivity at a radial distance r
double BSlabWaveguide::eps(double r)
{
    if ( r < (R + wg.hx(0)) )
	return wg.n(0)*wg.n(0);
    else if ( ((R + wg.hx(0)) <= r) && (r <= (R + wg.hx(1)) ))
	return wg.n(1)*wg.n(1);
    else
	return wg.n(2)*wg.n(2);
}

