/*
 * Circurs - Circular optical microresonators simulation tools
 * Kirankumar R. Hiremath (k.r.hiremath@ieee.org)
 * University of Twente, Department of Applied Mathematics 
 * P.O. Box 217, 7500AE Enschede, The Netherlands
 * (2005)
 */

#ifndef BSLAWAVEG_H
#define BSLAWAVEG_H

/* 
 * bslawaveh.h
 * bent slab waveguide definition
 */

#include <stdio.h>
#include "matrix.h"
#include "structure.h"

class BSlabWaveguide 
{
public:
	
    // cross section geometry, permittivity profile, wavelength
    // (See Metric codes for further details.)
    Waveguide wg;

    // bend radius: The Distance along the x-direction between the axis 
    // of the bend and the origin in the SlabWaveguide
    double R;

    // output to FILE dat
    void write(FILE *dat);

    // input from file dat 
    void read(FILE *dat);

    // constructor
    BSlabWaveguide();
    
    // constructor
    BSlabWaveguide(int numx);

    // constructor 
    BSlabWaveguide(Waveguide w, double r); 
    
    // (explicite) constructor
    BSlabWaveguide(int layer_,       // Number of dielectric layers
		   Dvector Bhx_,     // Position of above layers
		   double lambda_,   // Operational wavelength
		   Dvector Bn_,      // Refractive index profile
		   double R_         // Bent radius
	);
 
    //permittivity at cartesian position (x,z)
    double eps(double x, double z);
    
    //permittivity at a radial distance r
    double eps(double r);
    
};

#endif  // BSLAWAVEG_H
